@@ -2,7 +2,6 @@ from __future__ import print_function
 
 doc = r"""\
 The ``decorator`` module
-------------------------
 
 :Author: Michele Simionato
 :E-mail: michele.simionato@gmail.com
@@ -22,7 +21,7 @@ kicking. It is used by several frameworks (IPython, scipy, authkit,
 pylons, pycuda, sugar, ...) and has been stable for a *long*
 time. It is your best option if you want to preserve the signature of
 decorated functions in a consistent way across Python
-releases. Version 4.0 is fully compatible with the past, except for
+releases. Version 4 is fully compatible with the past, except for
 one thing: support for Python 2.4 and 2.5 has been dropped. That
 decision made it possible to use a single code base both for Python
 2.X and Python 3.X. This is a *huge* bonus, since I could remove over
@@ -72,7 +71,7 @@ What's New in version 4
 
 - **Python 3.5 coroutines**
   From version 4.1 it is possible to decorate coroutines, i.e. functions
-  defined with the `async def` syntax, and to mantain the
+  defined with the `async def` syntax, and to maintain the
   `inspect.iscoroutinefunction` check working for the decorated function.
 
 Usefulness of decorators
@@ -739,7 +738,7 @@ write code like the following:
      tasks = [make_task(3), make_task(2), make_task(1)]
      get_event_loop().run_until_complete(wait(tasks))
 
-and you will get at output like this::
+and you will get an output like this::
 
  INFO:root:Starting make_task(1,)
  INFO:root:Starting make_task(3,)
@@ -753,8 +752,23 @@ with a particularly complex chain of coroutines. With a single line you
 can decorate the troubling coroutine function, understand what happens, fix the
 issue and then remove the decorator (or keep it if continuous monitoring
 of the coroutines makes sense). Notice that
-`inspect.iscoroutinefunction(make_task)`
-will return then right answer (i.e. `True`).
+``inspect.iscoroutinefunction(make_task)``
+will return the right answer (i.e. ``True``).
+
+It is also possible to define decorators converting coroutine functions
+into regular functions, such as the following:
+
+.. code-block:: python
+
+ @decorator
+ def coro_to_func(coro, *args, **kw):
+     "Convert a coroutine into a function"
+     return get_event_loop().run_until_complete(coro(*args, **kw))
+
+Notice the diffence: the caller in ``log_start_stop`` was a coroutine
+function and the associate decorator was converting coroutines->coroutines;
+the caller in ``coro_to_func`` is a regular function and converts
+coroutines -> functions.
 
 Multiple dispatch
 -------------------------------------------
